Dabar - Multikino

Multikino

Aby w pełni wykorzystać możliwości naszej strony,
pobierz nowszą wersję programu Adobe Flash Player.

- Dabar
- Kalendorius

- ### Premjera

  #### Amžinai stilingos

  Biografinis / Dokumentinis / Komedija

- ### Premjera

  #### Robotų žemė

  Fantastinis / Trileris

- ### Premjera

  #### Serena

  Drama

- ### Premjera

  #### Užstrigusi paauglystėje

  Romantinė / Komedija

- ### Greitai

  #### Arvydas Sabonis. 11

  Dokumentinis

- ### Greitai

  #### Asteriksas. Dievų žemė 3D

  Animacija / Nuotykių

- ### Greitai

  #### Hobitas: Penkių armijų mūšis HFR 3D

  Fantastika / Nuotykių

- ### Greitai

  #### MultiKinukas: Aukso žirgas

  Animacija / Nuotykių / Šeimai

- ### Greitai

  #### Aukso žirgas

  Nuotykių / Šeimai / Animacinis

- ### Greitai

  #### Egzodas. Dievai ir karaliai

  Drama

- ### Greitai

  #### Geriausia, ką turiu

  Romantinė drama

- ### Greitai

  #### Šventa karvė

  Komedija

- ### Dabar rodome

  #### Kaip atsikratyti boso 2

  Komedija

- ### Dabar rodome

  #### Kol nenuėjau miegoti

  Trileris

- ### Dabar rodome

  #### Madagaskaro pingvinai 2D

  Animacija / Komedija / Šeimai / Nuotykių

- ### Dabar rodome

  #### Madagaskaro pingvinai 3D

  Animacija / Komedija / Šeimai / Nuotykių

- ### Dabar rodome

  #### Bado žaidynės: Strazdas giesmininkas. 1 dalis

  Mokslinė fantastika / Nuotykių / Veiksmo

- ### Dabar rodome

  #### Pakeliui N13

  Drama

- ### Dabar rodome

  #### Džesis ir Petas 3D

  Animacinis / Komedija

- ### Dabar rodome

  #### Tarp žvaigždžių

  Fantastinis / Mistinis

- ### Dabar rodome

  #### Mažylio Nikolia atostogos

  Komedija / Šeimai

- ### Dabar rodome

  #### Gustavo nuotykiai

  Animuotas

- ### Dabar rodome

  #### Visada geros kainos!

- ### Multibabykino

  #### MultiBabyKino: Amžinai stilingos

  Biografinis / Dokumentinis / Komedija

Užsiregistruok naujienlaiškiui
Naujienos
Daugiau naujienų
Multikino - Jūsų šeimos kino teatras

Šeimos bilietas

Velso aktorius ir muzikantas Rhysas Ifansas dramoje „Serena“ virto tyliu ir pavojingu medkirčiu

Kino naujienos

R.Scottas filmą „Egzodas: dievai ir karaliai“ skyrė savo brolio atminimui

Kino naujienos

Cate Blanchett: „Filme „Hobitas: Penkių armijų mūšis“ šviesioji elfė Galadrielė atskleis dar neregėtą jos pusę“

Kino naujienos

„Bukas ir bukesnis 2“ JAV šovė į žiūrimiausių filmų topo viršūnę

Kino naujienos